# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: veriservice.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='veriservice.proto',
  package='veriservice',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x11veriservice.proto\x12\x0bveriservice\"]\n\rSearchRequest\x12)\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x19.veriservice.SearchConfig\x12!\n\x05\x64\x61tum\x18\x02 \x03(\x0b\x32\x12.veriservice.Datum\"\xda\x01\n\x0cSearchConfig\x12\x15\n\rscoreFuncName\x18\x01 \x01(\t\x12\x16\n\x0ehigherIsBetter\x18\x02 \x01(\x08\x12\x11\n\ttimestamp\x18\x03 \x01(\x04\x12\x0f\n\x07timeout\x18\x04 \x01(\x04\x12\r\n\x05limit\x18\x05 \x01(\r\x12\x15\n\rcacheDuration\x18\x06 \x01(\x04\x12\x10\n\x08\x64\x61taName\x18\x07 \x01(\t\x12\x12\n\ngroupLimit\x18\x08 \x01(\r\x12\x1a\n\x12groupScoreFuncName\x18\t \x01(\t\x12\x0f\n\x07\x66ilters\x18\n \x03(\t\"\x1e\n\x0eGetDataRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"S\n\x05\x44\x61tum\x12\"\n\x03key\x18\x01 \x01(\x0b\x32\x15.veriservice.DatumKey\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.veriservice.DatumValue\"i\n\x08\x44\x61tumKey\x12\x0f\n\x07\x66\x65\x61ture\x18\x01 \x03(\x01\x12\x12\n\ngroupLabel\x18\x02 \x01(\x0c\x12\r\n\x05size1\x18\x03 \x01(\r\x12\r\n\x05size2\x18\x04 \x01(\r\x12\x0c\n\x04\x64im1\x18\x05 \x01(\r\x12\x0c\n\x04\x64im2\x18\x06 \x01(\r\",\n\nDatumValue\x12\x0f\n\x07version\x18\x01 \x01(\x04\x12\r\n\x05label\x18\x02 \x01(\x0c\"?\n\x0bScoredDatum\x12\r\n\x05score\x18\x01 \x01(\x01\x12!\n\x05\x64\x61tum\x18\x02 \x01(\x0b\x32\x12.veriservice.Datum\"e\n\x15InsertDatumWithConfig\x12)\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x19.veriservice.InsertConfig\x12!\n\x05\x64\x61tum\x18\x02 \x01(\x0b\x32\x12.veriservice.Datum\":\n\x0eSearchResponse\x12(\n\x06result\x18\x01 \x03(\x0b\x32\x18.veriservice.ScoredDatum\"r\n\x10InsertionRequest\x12)\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x19.veriservice.InsertConfig\x12!\n\x05\x64\x61tum\x18\x02 \x01(\x0b\x32\x12.veriservice.Datum\x12\x10\n\x08\x64\x61taName\x18\x03 \x01(\t\"\x1b\n\x0cInsertConfig\x12\x0b\n\x03tTL\x18\x01 \x01(\x04\"!\n\x11InsertionResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\"\xb5\x01\n\x08\x44\x61taInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x0b\n\x03\x61vg\x18\x04 \x03(\x01\x12\x0c\n\x04hist\x18\x05 \x03(\x01\x12\t\n\x01n\x18\x06 \x01(\x04\x12\x13\n\x0bmaxDistance\x18\x07 \x01(\x01\x12\x0f\n\x07targetN\x18\x08 \x01(\x04\x12\x19\n\x11TargetUtilization\x18\t \x01(\x01\x12\x10\n\x08NoTarget\x18\n \x01(\x08\"i\n\nDataConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0f\n\x07TargetN\x18\x03 \x01(\x04\x12\x19\n\x11TargetUtilization\x18\x04 \x01(\x01\x12\x10\n\x08NoTarget\x18\x05 \x01(\x08\"\xa4\x01\n\x04Peer\x12\x13\n\x0b\x61\x64\x64ressList\x18\x01 \x03(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x04\x12)\n\x08\x64\x61taList\x18\x04 \x03(\x0b\x32\x17.veriservice.DataConfig\x12\x13\n\x0bserviceList\x18\x05 \x03(\t\x12#\n\x08peerList\x18\x06 \x03(\x0b\x32\x11.veriservice.Peer\".\n\x0bJoinRequest\x12\x1f\n\x04peer\x18\x01 \x01(\x0b\x32\x11.veriservice.Peer\"\x1f\n\x0cJoinResponse\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t2\xf9\x03\n\x0bVeriService\x12\x43\n\x06Search\x12\x1a.veriservice.SearchRequest\x1a\x1b.veriservice.SearchResponse\"\x00\x12I\n\x06Insert\x12\x1d.veriservice.InsertionRequest\x1a\x1e.veriservice.InsertionResponse\"\x00\x12=\n\x04Join\x12\x18.veriservice.JoinRequest\x1a\x19.veriservice.JoinResponse\"\x00\x12\x41\n\nDataStream\x12\x1b.veriservice.GetDataRequest\x1a\x12.veriservice.Datum\"\x00\x30\x01\x12I\n\x15\x43reateDataIfNotExists\x12\x17.veriservice.DataConfig\x1a\x15.veriservice.DataInfo\"\x00\x12\x43\n\x0bGetDataInfo\x12\x1b.veriservice.GetDataRequest\x1a\x15.veriservice.DataInfo\"\x00\x12H\n\x0cSearchStream\x12\x1a.veriservice.SearchRequest\x1a\x18.veriservice.ScoredDatum\"\x00\x30\x01\x62\x06proto3'
)




_SEARCHREQUEST = _descriptor.Descriptor(
  name='SearchRequest',
  full_name='veriservice.SearchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='veriservice.SearchRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datum', full_name='veriservice.SearchRequest.datum', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34,
  serialized_end=127,
)


_SEARCHCONFIG = _descriptor.Descriptor(
  name='SearchConfig',
  full_name='veriservice.SearchConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreFuncName', full_name='veriservice.SearchConfig.scoreFuncName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='higherIsBetter', full_name='veriservice.SearchConfig.higherIsBetter', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='veriservice.SearchConfig.timestamp', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='veriservice.SearchConfig.timeout', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='veriservice.SearchConfig.limit', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cacheDuration', full_name='veriservice.SearchConfig.cacheDuration', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataName', full_name='veriservice.SearchConfig.dataName', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groupLimit', full_name='veriservice.SearchConfig.groupLimit', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groupScoreFuncName', full_name='veriservice.SearchConfig.groupScoreFuncName', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='veriservice.SearchConfig.filters', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=130,
  serialized_end=348,
)


_GETDATAREQUEST = _descriptor.Descriptor(
  name='GetDataRequest',
  full_name='veriservice.GetDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='veriservice.GetDataRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=350,
  serialized_end=380,
)


_DATUM = _descriptor.Descriptor(
  name='Datum',
  full_name='veriservice.Datum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='veriservice.Datum.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='veriservice.Datum.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=382,
  serialized_end=465,
)


_DATUMKEY = _descriptor.Descriptor(
  name='DatumKey',
  full_name='veriservice.DatumKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature', full_name='veriservice.DatumKey.feature', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groupLabel', full_name='veriservice.DatumKey.groupLabel', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size1', full_name='veriservice.DatumKey.size1', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size2', full_name='veriservice.DatumKey.size2', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dim1', full_name='veriservice.DatumKey.dim1', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dim2', full_name='veriservice.DatumKey.dim2', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=467,
  serialized_end=572,
)


_DATUMVALUE = _descriptor.Descriptor(
  name='DatumValue',
  full_name='veriservice.DatumValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='veriservice.DatumValue.version', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label', full_name='veriservice.DatumValue.label', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=574,
  serialized_end=618,
)


_SCOREDDATUM = _descriptor.Descriptor(
  name='ScoredDatum',
  full_name='veriservice.ScoredDatum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='score', full_name='veriservice.ScoredDatum.score', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datum', full_name='veriservice.ScoredDatum.datum', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=620,
  serialized_end=683,
)


_INSERTDATUMWITHCONFIG = _descriptor.Descriptor(
  name='InsertDatumWithConfig',
  full_name='veriservice.InsertDatumWithConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='veriservice.InsertDatumWithConfig.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datum', full_name='veriservice.InsertDatumWithConfig.datum', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=685,
  serialized_end=786,
)


_SEARCHRESPONSE = _descriptor.Descriptor(
  name='SearchResponse',
  full_name='veriservice.SearchResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='veriservice.SearchResponse.result', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=788,
  serialized_end=846,
)


_INSERTIONREQUEST = _descriptor.Descriptor(
  name='InsertionRequest',
  full_name='veriservice.InsertionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='veriservice.InsertionRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datum', full_name='veriservice.InsertionRequest.datum', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataName', full_name='veriservice.InsertionRequest.dataName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=848,
  serialized_end=962,
)


_INSERTCONFIG = _descriptor.Descriptor(
  name='InsertConfig',
  full_name='veriservice.InsertConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tTL', full_name='veriservice.InsertConfig.tTL', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=964,
  serialized_end=991,
)


_INSERTIONRESPONSE = _descriptor.Descriptor(
  name='InsertionResponse',
  full_name='veriservice.InsertionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='veriservice.InsertionResponse.code', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=993,
  serialized_end=1026,
)


_DATAINFO = _descriptor.Descriptor(
  name='DataInfo',
  full_name='veriservice.DataInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='veriservice.DataInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='veriservice.DataInfo.timestamp', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='veriservice.DataInfo.version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avg', full_name='veriservice.DataInfo.avg', index=3,
      number=4, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hist', full_name='veriservice.DataInfo.hist', index=4,
      number=5, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='n', full_name='veriservice.DataInfo.n', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maxDistance', full_name='veriservice.DataInfo.maxDistance', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetN', full_name='veriservice.DataInfo.targetN', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='TargetUtilization', full_name='veriservice.DataInfo.TargetUtilization', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='NoTarget', full_name='veriservice.DataInfo.NoTarget', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1029,
  serialized_end=1210,
)


_DATACONFIG = _descriptor.Descriptor(
  name='DataConfig',
  full_name='veriservice.DataConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='veriservice.DataConfig.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='veriservice.DataConfig.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='TargetN', full_name='veriservice.DataConfig.TargetN', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='TargetUtilization', full_name='veriservice.DataConfig.TargetUtilization', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='NoTarget', full_name='veriservice.DataConfig.NoTarget', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1212,
  serialized_end=1317,
)


_PEER = _descriptor.Descriptor(
  name='Peer',
  full_name='veriservice.Peer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='addressList', full_name='veriservice.Peer.addressList', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='veriservice.Peer.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='veriservice.Peer.timestamp', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataList', full_name='veriservice.Peer.dataList', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serviceList', full_name='veriservice.Peer.serviceList', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='peerList', full_name='veriservice.Peer.peerList', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1320,
  serialized_end=1484,
)


_JOINREQUEST = _descriptor.Descriptor(
  name='JoinRequest',
  full_name='veriservice.JoinRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='peer', full_name='veriservice.JoinRequest.peer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1486,
  serialized_end=1532,
)


_JOINRESPONSE = _descriptor.Descriptor(
  name='JoinResponse',
  full_name='veriservice.JoinResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='veriservice.JoinResponse.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1534,
  serialized_end=1565,
)

_SEARCHREQUEST.fields_by_name['config'].message_type = _SEARCHCONFIG
_SEARCHREQUEST.fields_by_name['datum'].message_type = _DATUM
_DATUM.fields_by_name['key'].message_type = _DATUMKEY
_DATUM.fields_by_name['value'].message_type = _DATUMVALUE
_SCOREDDATUM.fields_by_name['datum'].message_type = _DATUM
_INSERTDATUMWITHCONFIG.fields_by_name['config'].message_type = _INSERTCONFIG
_INSERTDATUMWITHCONFIG.fields_by_name['datum'].message_type = _DATUM
_SEARCHRESPONSE.fields_by_name['result'].message_type = _SCOREDDATUM
_INSERTIONREQUEST.fields_by_name['config'].message_type = _INSERTCONFIG
_INSERTIONREQUEST.fields_by_name['datum'].message_type = _DATUM
_PEER.fields_by_name['dataList'].message_type = _DATACONFIG
_PEER.fields_by_name['peerList'].message_type = _PEER
_JOINREQUEST.fields_by_name['peer'].message_type = _PEER
DESCRIPTOR.message_types_by_name['SearchRequest'] = _SEARCHREQUEST
DESCRIPTOR.message_types_by_name['SearchConfig'] = _SEARCHCONFIG
DESCRIPTOR.message_types_by_name['GetDataRequest'] = _GETDATAREQUEST
DESCRIPTOR.message_types_by_name['Datum'] = _DATUM
DESCRIPTOR.message_types_by_name['DatumKey'] = _DATUMKEY
DESCRIPTOR.message_types_by_name['DatumValue'] = _DATUMVALUE
DESCRIPTOR.message_types_by_name['ScoredDatum'] = _SCOREDDATUM
DESCRIPTOR.message_types_by_name['InsertDatumWithConfig'] = _INSERTDATUMWITHCONFIG
DESCRIPTOR.message_types_by_name['SearchResponse'] = _SEARCHRESPONSE
DESCRIPTOR.message_types_by_name['InsertionRequest'] = _INSERTIONREQUEST
DESCRIPTOR.message_types_by_name['InsertConfig'] = _INSERTCONFIG
DESCRIPTOR.message_types_by_name['InsertionResponse'] = _INSERTIONRESPONSE
DESCRIPTOR.message_types_by_name['DataInfo'] = _DATAINFO
DESCRIPTOR.message_types_by_name['DataConfig'] = _DATACONFIG
DESCRIPTOR.message_types_by_name['Peer'] = _PEER
DESCRIPTOR.message_types_by_name['JoinRequest'] = _JOINREQUEST
DESCRIPTOR.message_types_by_name['JoinResponse'] = _JOINRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SearchRequest = _reflection.GeneratedProtocolMessageType('SearchRequest', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHREQUEST,
  '__module__' : 'veriservice_pb2'
  # @@protoc_insertion_point(class_scope:veriservice.SearchRequest)
  })
_sym_db.RegisterMessage(SearchRequest)

SearchConfig = _reflection.GeneratedProtocolMessageType('SearchConfig', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHCONFIG,
  '__module__' : 'veriservice_pb2'
  # @@protoc_insertion_point(class_scope:veriservice.SearchConfig)
  })
_sym_db.RegisterMessage(SearchConfig)

GetDataRequest = _reflection.GeneratedProtocolMessageType('GetDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAREQUEST,
  '__module__' : 'veriservice_pb2'
  # @@protoc_insertion_point(class_scope:veriservice.GetDataRequest)
  })
_sym_db.RegisterMessage(GetDataRequest)

Datum = _reflection.GeneratedProtocolMessageType('Datum', (_message.Message,), {
  'DESCRIPTOR' : _DATUM,
  '__module__' : 'veriservice_pb2'
  # @@protoc_insertion_point(class_scope:veriservice.Datum)
  })
_sym_db.RegisterMessage(Datum)

DatumKey = _reflection.GeneratedProtocolMessageType('DatumKey', (_message.Message,), {
  'DESCRIPTOR' : _DATUMKEY,
  '__module__' : 'veriservice_pb2'
  # @@protoc_insertion_point(class_scope:veriservice.DatumKey)
  })
_sym_db.RegisterMessage(DatumKey)

DatumValue = _reflection.GeneratedProtocolMessageType('DatumValue', (_message.Message,), {
  'DESCRIPTOR' : _DATUMVALUE,
  '__module__' : 'veriservice_pb2'
  # @@protoc_insertion_point(class_scope:veriservice.DatumValue)
  })
_sym_db.RegisterMessage(DatumValue)

ScoredDatum = _reflection.GeneratedProtocolMessageType('ScoredDatum', (_message.Message,), {
  'DESCRIPTOR' : _SCOREDDATUM,
  '__module__' : 'veriservice_pb2'
  # @@protoc_insertion_point(class_scope:veriservice.ScoredDatum)
  })
_sym_db.RegisterMessage(ScoredDatum)

InsertDatumWithConfig = _reflection.GeneratedProtocolMessageType('InsertDatumWithConfig', (_message.Message,), {
  'DESCRIPTOR' : _INSERTDATUMWITHCONFIG,
  '__module__' : 'veriservice_pb2'
  # @@protoc_insertion_point(class_scope:veriservice.InsertDatumWithConfig)
  })
_sym_db.RegisterMessage(InsertDatumWithConfig)

SearchResponse = _reflection.GeneratedProtocolMessageType('SearchResponse', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHRESPONSE,
  '__module__' : 'veriservice_pb2'
  # @@protoc_insertion_point(class_scope:veriservice.SearchResponse)
  })
_sym_db.RegisterMessage(SearchResponse)

InsertionRequest = _reflection.GeneratedProtocolMessageType('InsertionRequest', (_message.Message,), {
  'DESCRIPTOR' : _INSERTIONREQUEST,
  '__module__' : 'veriservice_pb2'
  # @@protoc_insertion_point(class_scope:veriservice.InsertionRequest)
  })
_sym_db.RegisterMessage(InsertionRequest)

InsertConfig = _reflection.GeneratedProtocolMessageType('InsertConfig', (_message.Message,), {
  'DESCRIPTOR' : _INSERTCONFIG,
  '__module__' : 'veriservice_pb2'
  # @@protoc_insertion_point(class_scope:veriservice.InsertConfig)
  })
_sym_db.RegisterMessage(InsertConfig)

InsertionResponse = _reflection.GeneratedProtocolMessageType('InsertionResponse', (_message.Message,), {
  'DESCRIPTOR' : _INSERTIONRESPONSE,
  '__module__' : 'veriservice_pb2'
  # @@protoc_insertion_point(class_scope:veriservice.InsertionResponse)
  })
_sym_db.RegisterMessage(InsertionResponse)

DataInfo = _reflection.GeneratedProtocolMessageType('DataInfo', (_message.Message,), {
  'DESCRIPTOR' : _DATAINFO,
  '__module__' : 'veriservice_pb2'
  # @@protoc_insertion_point(class_scope:veriservice.DataInfo)
  })
_sym_db.RegisterMessage(DataInfo)

DataConfig = _reflection.GeneratedProtocolMessageType('DataConfig', (_message.Message,), {
  'DESCRIPTOR' : _DATACONFIG,
  '__module__' : 'veriservice_pb2'
  # @@protoc_insertion_point(class_scope:veriservice.DataConfig)
  })
_sym_db.RegisterMessage(DataConfig)

Peer = _reflection.GeneratedProtocolMessageType('Peer', (_message.Message,), {
  'DESCRIPTOR' : _PEER,
  '__module__' : 'veriservice_pb2'
  # @@protoc_insertion_point(class_scope:veriservice.Peer)
  })
_sym_db.RegisterMessage(Peer)

JoinRequest = _reflection.GeneratedProtocolMessageType('JoinRequest', (_message.Message,), {
  'DESCRIPTOR' : _JOINREQUEST,
  '__module__' : 'veriservice_pb2'
  # @@protoc_insertion_point(class_scope:veriservice.JoinRequest)
  })
_sym_db.RegisterMessage(JoinRequest)

JoinResponse = _reflection.GeneratedProtocolMessageType('JoinResponse', (_message.Message,), {
  'DESCRIPTOR' : _JOINRESPONSE,
  '__module__' : 'veriservice_pb2'
  # @@protoc_insertion_point(class_scope:veriservice.JoinResponse)
  })
_sym_db.RegisterMessage(JoinResponse)



_VERISERVICE = _descriptor.ServiceDescriptor(
  name='VeriService',
  full_name='veriservice.VeriService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1568,
  serialized_end=2073,
  methods=[
  _descriptor.MethodDescriptor(
    name='Search',
    full_name='veriservice.VeriService.Search',
    index=0,
    containing_service=None,
    input_type=_SEARCHREQUEST,
    output_type=_SEARCHRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Insert',
    full_name='veriservice.VeriService.Insert',
    index=1,
    containing_service=None,
    input_type=_INSERTIONREQUEST,
    output_type=_INSERTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Join',
    full_name='veriservice.VeriService.Join',
    index=2,
    containing_service=None,
    input_type=_JOINREQUEST,
    output_type=_JOINRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DataStream',
    full_name='veriservice.VeriService.DataStream',
    index=3,
    containing_service=None,
    input_type=_GETDATAREQUEST,
    output_type=_DATUM,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateDataIfNotExists',
    full_name='veriservice.VeriService.CreateDataIfNotExists',
    index=4,
    containing_service=None,
    input_type=_DATACONFIG,
    output_type=_DATAINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDataInfo',
    full_name='veriservice.VeriService.GetDataInfo',
    index=5,
    containing_service=None,
    input_type=_GETDATAREQUEST,
    output_type=_DATAINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SearchStream',
    full_name='veriservice.VeriService.SearchStream',
    index=6,
    containing_service=None,
    input_type=_SEARCHREQUEST,
    output_type=_SCOREDDATUM,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_VERISERVICE)

DESCRIPTOR.services_by_name['VeriService'] = _VERISERVICE

# @@protoc_insertion_point(module_scope)
